@@ -2,17 +2,11 @@ from nltk.tokenize import word_tokenize
 from nltk.corpus import wordnet
 from finntk.emb.base import BothVectorSpaceAdapter, MonoVectorSpaceAdapter
 from finntk.emb.utils import apply_vec
-from finntk.vendor.metanl.nltk_morphy import tag_and_stem
+from finntk.lemmatize_en import default_lemmatize_en
 from finntk.wordnet.reader import fiwn
 from itertools import repeat
 
 
-def lemmatize_tokens(tokens):
-    # TODO: Consider switching to ConceptNet5 or Stanford taggger for lemmatization
-    # TODO: Consider not doing lemmatization at all and just relying on glosswordnet
-    return (stem for (stem, _, _) in tag_and_stem(tokens))
-
-
 def unexpanded_defn_getter(lemma):
     return word_tokenize(lemma.synset().definition())
 
@@ -59,7 +53,7 @@ def expanded_defn_getter(lemma):
         elif relation == "Similar to":
             related_synsets.update(synset.similar_tos())
         elif relation == "Pertainym of":
-            related_synsets.update((l.synset() for l in lemma.pertainyms()))
+            related_synsets.update((lemma.synset() for lemma in lemma.pertainyms()))
         else:
             assert False, "Unknown relation"
     tokens = []
@@ -106,7 +100,6 @@ def wn_filter_stream(wn, stream):
 
 
 class MultilingualLesk:
-
     def __init__(self, multispace, aggf, wn_filter=False, expand=False, use_freq=False):
         self.multispace = multispace
         self.defn_space = BothVectorSpaceAdapter(
@@ -126,7 +119,8 @@ class MultilingualLesk:
         else:
             defn_tokens = unexpanded_defn_getter(item)
 
-        lemmatized = lemmatize_tokens(defn_tokens)
+        # TODO: Consider not doing lemmatization at all and just relying on glosswordnet
+        lemmatized = default_lemmatize_en(defn_tokens)
         stream = zip(defn_tokens, lemmatized)
         if self.wn_filter:
             stream = wn_filter_stream(wordnet, stream)
